@@ -1,7 +1,7 @@
 """
-=======================================
-Plot the distribution of missing values
-=======================================
+==================================================
+Basic: Plotting the distribution of missing values
+==================================================
 
 UpSet plots are often used to show which variables are missing together.
 
@@ -9,11 +9,14 @@ Passing a callable ``indicators=pd.isna`` to :func:`from_indicators` is
 an easy way to categorise a record by the variables that are missing in it.
 """
 
-from matplotlib import pyplot as plt
 import pandas as pd
-from upsetplot import plot, from_indicators
+from matplotlib import pyplot as plt
 
-TITANIC_URL = 'https://raw.githubusercontent.com/datasciencedojo/datasets/master/titanic.csv'  # noqa
+from upsetplot import from_indicators, plot
+
+TITANIC_URL = (
+    "https://raw.githubusercontent.com/datasciencedojo/datasets/master/titanic.csv"  # noqa
+)
 data = pd.read_csv(TITANIC_URL)
 
 plot(from_indicators(indicators=pd.isna, data=data), show_counts=True)
