@@ -1,19 +1,20 @@
 """
-========================================
-Customising element size and figure size
-========================================
+================================================
+Design: Customizing element size and figure size
+================================================
 
 This example illustrates controlling sizing within an UpSet plot.
 """
 
 from matplotlib import pyplot as plt
+
 from upsetplot import generate_counts, plot
 
 example = generate_counts()
 print(example)
 
 plot(example)
-plt.suptitle('Defaults')
+plt.suptitle("Defaults")
 plt.show()
 
 ##########################################################################
@@ -21,7 +22,7 @@ plt.show()
 # size of these elements affects all components of the plot.
 
 plot(example, element_size=40)
-plt.suptitle('Increased element_size')
+plt.suptitle("Increased element_size")
 plt.show()
 
 ##########################################################################
@@ -30,7 +31,7 @@ plt.show()
 
 fig = plt.figure(figsize=(10, 3))
 plot(example, fig=fig, element_size=None)
-plt.suptitle('Setting figsize explicitly')
+plt.suptitle("Setting figsize explicitly")
 plt.show()
 
 ##########################################################################
@@ -38,11 +39,11 @@ plt.show()
 # they should equate to.
 
 plot(example, intersection_plot_elements=3)
-plt.suptitle('Decreased intersection_plot_elements')
+plt.suptitle("Decreased intersection_plot_elements")
 plt.show()
 
 ##########################################################################
 
 plot(example, totals_plot_elements=5)
-plt.suptitle('Increased totals_plot_elements')
+plt.suptitle("Increased totals_plot_elements")
 plt.show()
